@@ -27,7 +27,6 @@
 #include <KLocalizedString>
 
 #include "docentrytraverser.h"
-#include <ki18n_version.h>
 
 #include <prefs.h>
 
@@ -193,7 +192,7 @@ DocEntry *DocMetaInfo::scanMetaInfoDir( const QString &dirName,
 
 DocEntry *DocMetaInfo::addDirEntry( const QDir &dir, DocEntry *parent )
 {
-  DocEntry *dirEntry = addDocEntry( dir.absoluteFilePath( QLatin1String(".directory") ) );
+  DocEntry *dirEntry = addDocEntry( dir.absoluteFilePath( QStringLiteral(".directory") ) );
 
   if ( !dirEntry ) 
   {
